# Remove PDF last page

This package removes pages appended by publishers or registries.

Examples are:

- CAIS
- ME Sharpe

## pdf-prep

This package is included in many default setups. To add it to a project, run

```
colrev pdf-prep -a colrev.remove_last_page
```
